from sklearn import datasets, model_selection
import joblib

print('MNISTの取得：', end='', flush=True)
try:
    data = joblib.load('lr.data')
    label = joblib.load('lr.label')
except:
    mnist = datasets.fetch_openml('mnist_784')
    data = mnist.data.astype('float32')/255
    label = mnist.target.astype('int32')
    joblib.dump(data, 'lr.data')
    joblib.dump(label, 'lr.label')
print('完了')

TRAIN_SIZE = 60000
TEST_SIZE = 10000

t = model_selection.train_test_split(
    data, label, train_size=TRAIN_SIZE, test_size=TEST_SIZE)
train_data, test_data, train_label, test_label = t
print('訓練データ：', train_data.shape)
print('テストデータ：', test_data.shape)

model = joblib.load('lr.model')

print('テスト結果：')
predict = model.predict(test_data)

count = [[0 for i in range(10)] for j in range(10)]
label = list(test_label)
for i in range(TEST_SIZE):
    count[predict[i]][label[i]] += 1
print('正解   ', end='')
for i in range(10):
    print('   [{0}]'.format(i), end='')
print()
for i in range(10):
    print('予測[{0}]'.format(i), end='')
    for j in range(10):
        print('{0:6d}'.format(count[i][j]), end='')
    print()

print('正解率：', model.score(test_data, test_label)*100, '%')
